branch: elpa/llama
commit fe7999efef52a9b0d22a99d8028007a330dd0aa4
Author: Jonas Bernoulli <jo...@bernoul.li>
Commit: Jonas Bernoulli <jo...@bernoul.li>

    Be explicit about % and %N being mandatory
---
 README.org | 10 +++++-----
 llama.el   | 20 ++++++++++----------
 2 files changed, 15 insertions(+), 15 deletions(-)

diff --git a/README.org b/README.org
index 7a64a68767..1f9dd6bb86 100644
--- a/README.org
+++ b/README.org
@@ -14,11 +14,11 @@ BODY and returns its value.  Its own arguments are derived 
from
 symbols found in BODY.
 
 Each symbol from ~%1~ through ~%9~, which appears in BODY,
-specifies an argument.  Each symbol from ~&1~ through ~&9~, which
-appears in BODY, specifies an optional argument.  All arguments
-following an optional argument have to be optional as well, thus
-their names have to begin with ~&~.  Symbol ~&*~ specifies extra
-(~&rest~) arguments.
+specifies a mandatory argument.  Each symbol from ~&1~ through
+~&9~, which appears in BODY, specifies an optional argument.
+All arguments following an optional argument have to be optional
+as well, thus their names have to begin with ~&~.  Symbol ~&*~
+specifies extra (~&rest~) arguments.
 
 The shorter symbol ~%~ can be used instead of ~%1~, but using both
 in the same expression is not allowed.  Likewise ~&~ can be used
diff --git a/llama.el b/llama.el
index c0ca3a5711..2f3c407aee 100644
--- a/llama.el
+++ b/llama.el
@@ -39,11 +39,11 @@
 ;; symbols found in ARGS.
 
 ;; Each symbol from `%1' through `%9', which appears in BODY,
 ;; specifies an argument.  Each symbol from `&1' through `&9', which
 ;; appears in BODY, specifies an optional argument.  All arguments
 ;; following an optional argument have to be optional as well, thus
 ;; their names have to begin with `&'.  Symbol `&*' specifies extra
 ;; (`&rest') arguments.
 
 ;; The shorter symbol `%' can be used instead of `%1', but using both
 ;; in the same expression is not allowed.  Likewise `&' can be used
@@ -92,11 +92,11 @@ BODY and returns its value.  Its own arguments are derived 
from
 symbols found in BODY.
 
 Each symbol from `%1' through `%9', which appears in BODY,
-specifies an argument.  Each symbol from `&1' through `&9', which
-appears in BODY, specifies an optional argument.  All arguments
-following an optional argument have to be optional as well, thus
-their names have to begin with `&'.  Symbol `&*' specifies extra
-\(`&rest') arguments.
+specifies a mandatory argument.  Each symbol from `&1' through
+`&9', which appears in BODY, specifies an optional argument.
+All arguments following an optional argument have to be optional
+as well, thus their names have to begin with `&'.  Symbol `&*'
+specifies extra (`&rest') arguments.
 
 The shorter symbol `%' can be used instead of `%1', but using both
 in the same expression is not allowed.  Likewise `&' can be used
@@ -39,11 +39,11 @@
 
 ;; Each symbol from `%1' through `%9', which appears in BODY,
-;; specifies an argument.  Each symbol from `&1' through `&9', which
-;; appears in BODY, specifies an optional argument.  All arguments
-;; following an optional argument have to be optional as well, thus
-;; their names have to begin with `&'.  Symbol `&*' specifies extra
-;; (`&rest') arguments.
+;; specifies a mandatory argument.  Each symbol from `&1' through
+;; `&9', which appears in BODY, specifies an optional argument.
+;; All arguments following an optional argument have to be optional
+;; as well, thus their names have to begin with `&'.  Symbol `&*'
+;; specifies extra (`&rest') arguments.
 
 ;; The shorter symbol `%' can be used instead of `%1', but using both

Reply via email to